controllers

package
v0.2.58 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 23, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

controllers/async_runner.go

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewClientController

func NewClientController(svc services.ClientService, cfg *config.Config) *clientController

func NewDeleteController

func NewDeleteController(svc services.UserService, cfg *config.Config) *deleteController

NewDeleteController wires dependencies for user deletion endpoints.

func NewJWKSController

func NewJWKSController(svc services.UserService) *jwksController

func NewListController

func NewListController(u services.UserService, c *config.Config) *listController

NewListController wires the list endpoint with the service and config.

func NewLookupController

func NewLookupController(svc services.UserService, cfg *config.Config) *lookupController

NewLookupController returns a controller that can translate Firebase-style lookup calls.

func NewMembershipController

func NewMembershipController(svc services.MembershipService, cfg *config.Config) *membershipController

func NewOobDispatchController

func NewOobDispatchController(svc services.UserService) *oobDispatchController

func NewOobResetController

func NewOobResetController(svc services.UserService, cfg *config.Config) *oobResetController

NewOobResetController builds the controller used to reset passwords with received codes.

func NewOobSendController

func NewOobSendController(svc services.UserService, cfg *config.Config) *oobSendController

NewOobSendController builds the controller that sends OOB codes via the service.

func NewOobSignInController

func NewOobSignInController(svc services.UserService) *oobSignInController

NewOobSignInController creates a controller instance for OOB sign-in requests.

func NewRoleController

func NewRoleController(svc services.RoleService, cfg *config.Config) *roleController

func NewSignUpController

func NewSignUpController(svc services.UserService, cfg *config.Config) *signUpController

NewSignUpController initializes the sign-up endpoint with the service and config.

func NewTenantController

func NewTenantController(svc services.TenantService, cfg *config.Config) *tenantController

func NewTokenExchangeController

func NewTokenExchangeController(svc services.UserService) *tokenExchangeController

NewTokenExchangeController builds a controller for token exchange.

func NewUpdateController

func NewUpdateController(svc services.UserService, cfg *config.Config) *updateController

NewUpdateController prepares the controller with a service and configuration.

func NewUserAdminController

func NewUserAdminController(svc services.UserService, cfg *config.Config) *userAdminController

func NewValidateController

func NewValidateController(svc services.UserService, cfg *config.Config) *validateController

func NewWorkloadIdentityController added in v0.2.57

func NewWorkloadIdentityController(service services.WorkloadIdentityService) *workloadIdentityController

Types

type SignInController

type SignInController struct {
	// contains filtered or unexported fields
}

SignInController authenticates users and returns Firebase-compatible tokens.

func NewSignInController

func NewSignInController(u services.UserService, c *config.Config) *SignInController

NewSignInController creates a controller instance that can service sign-in requests.

func (*SignInController) Handle

func (ctrl *SignInController) Handle(ctx *gin.Context)

Handle binds request JSON, authenticates with the user service and returns the response.

Jump to